# Clot v.0.0.2

<p align="right"> <img src="https://komarev.com/ghpvc/?username=merwin-asm-clot&label=Project%20views&color=0e75b6&style=flat" alt="darkmash-org" /> </p>

[![Downloads](https://static.pepy.tech/badge/clot-terminal)](https://pepy.tech/project/clot-terminal)

<img src="https://media.discordapp.net/attachments/951417646191083551/1090963610383167528/image.png?width=500&height=250">

## About
A terminal which have some random cool features.

### Present Features:

 - History
 - Colorfull Foreground
 - Made for Windows and Linux users
 - Command Book \[A place to notedown commands and stuff]

## Installation

```
  pip install clot-terminal
```

Or run with out installing

```
 git clone https://github.com/merwin-asm/Clot.git
```

```    
  cd Clot
```

```
  python3 main.py
```

### How to use ?

Just open your terminal and type in clot :)

## Updating

Type in update to any clot session

```
  update
```

## Exiting

Type in exit

``` 
 exit
```

## Preview
<p align="center">
<img src="https://media.discordapp.net/attachments/951417646191083551/1090967924220633168/image.png">
</p>

<p align="center">
<img src="https://cdn.discordapp.com/attachments/951417646191083551/1090291584207159366/image.png">
</p>

### Note :
  - This terminal may be lacking some features which others offer like , going back to previous commands. \[ We be fixin it ]
  - Some tools like vim doesnt work on it... \[ We will fix it]
  - The terminal is slow at printing when you run somethin which takes hella time. \[ Will be def fixed]
  
<hr>

## Collabing and Donating

- Dm on ma discord - cactochan#2004 , If you wanna give some suggestions or you wanna collab with me..

- Duino coin - cacti

- BNB / Eth - 0x9CE5E2179A95Ba94f1B723FbfAd4710a9891c9e3

- Patreon - cactochan
